OAuthConfiguration class

OAuth Configuration

Constructors

OAuthConfiguration({required OAuthProvider provider, required String redirectURI, List<String>? scope, String? loginHint})

Properties

hashCode → int
The hash code for this object.
no setterinherited
loginHint ↔ String?
getter/setter pair
provider ↔ OAuthProvider
getter/setter pair
redirectURI ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited